@@ -73,7 +73,7 @@ extensions = [
     "sphinx.ext.ifconfig",
     "sphinx.ext.mathjax",
     "sphinx.ext.napoleon",
-    "sphinx_rtd_theme",
+    "sphinx_rtd_theme"
 ]
 
 # Add any paths that contain templates here, relative to this directory.
@@ -150,8 +150,6 @@ pygments_style = "sphinx"
 # If this is True, todo emits a warning for each TODO entries. The default is False.
 todo_emit_warnings = True
 
-# Since the documentation build process doesn't need to make actual database connections, we can mock the pyodbc module during the documentation build.
-autodoc_mock_imports = ["pyodbc"]
 
 # -- Options for HTML output -------------------------------------------------
 
@@ -250,13 +248,7 @@ latex_elements = {
 # Grouping the document tree into LaTeX files. List of tuples
 # (source start file, target name, title, author, documentclass [howto/manual]).
 latex_documents = [
-    (
-        "index",
-        "user_guide.tex",
-        "pyPrediktorMapClient Documentation",
-        "Prediktor Support",
-        "manual",
-    )
+    ("index", "user_guide.tex", "pyPrediktorMapClient Documentation", "Prediktor Support", "manual")
 ]
 
 # The name of an image file (relative to this directory) to place at the top of
