@@ -1,6 +1,5 @@
 import sys
-from .shared import *
-from .analytics_helper import *
+from .pyprediktormapclient_shared import *
 from .model_index import *
 from .opc_ua import *
 
